import React from 'react';
import { ComponentStory, Meta } from '@storybook/react';
import { RawJSONVis } from './rawjsonvis';

import { assignNewGraphQueryResult, graphQueryResultSlice, resetGraphQueryResults, store } from '../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import { mockLargeQueryResults } from '../../mock-data/query-result';

const Component: Meta<typeof RawJSONVis> = {
  /* 👇 The title prop is optional.
   * See https://storybook.js.org/docs/react/configure/overview#configure-story-loading
   * to learn how to generate automatic titles
   */
  title: 'Components/Visualizations/RawJSONVIS',
  component: RawJSONVis,
  decorators: [(story) => <Provider store={Mockstore}>{story()}</Provider>],
};

const Mockstore = configureStore({
  reducer: {
    graphQueryResult: graphQueryResultSlice.reducer,
  },
});

export const SimpleData = {
  args: {
    loading: false,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(
      assignNewGraphQueryResult({
        type: 'nodelink',
        payload: {
          nodes: [
            { id: 'agent/007', attributes: { name: 'Daniel Craig' } },
            { id: 'villain', attributes: { name: 'Le Chiffre' } },
          ],
          edges: [],
        },
      })
    );
  },
};

export const LargeData = {
  args: {
    loading: false,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(
      assignNewGraphQueryResult({
        type: 'nodelink',
        payload: mockLargeQueryResults,
      })
    );
  },
};

export const Loading = {
  args: {
    loading: true,
  },
};

export const Empty = {
  args: {
    loading: false,
  },
  play: async () => {
    const dispatch = store.dispatch;
    dispatch(resetGraphQueryResults());
  },
};

export default Component;
